##  Localization
The Localization tabs allows manual Language Translation / Localization of the portal as needed.
![Localization tab in SAP LeanIX portal configuration with editable language fields.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757bb7f7a4410148c2da33efa8f6fc4_LowRes.png)
